summaryrefslogtreecommitdiff
path: root/camlibs/ptp2/library.c
diff options
context:
space:
mode:
Diffstat (limited to 'camlibs/ptp2/library.c')
-rw-r--r--camlibs/ptp2/library.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/camlibs/ptp2/library.c b/camlibs/ptp2/library.c
index adc3bec5a..217ae36ea 100644
--- a/camlibs/ptp2/library.c
+++ b/camlibs/ptp2/library.c
@@ -3582,7 +3582,7 @@ capturetriggered:
CR (gp_port_set_timeout (camera->port, capture_timeout));
- C_PTP_REP (nikon_wait_busy (params, 100, 20000)); /* lets wait 20 seconds */
+ C_PTP_REP (nikon_wait_busy (params, 100, 200*1000)); /* lets wait 200 seconds */
newobject = 0xffff0001;
done = 0; tries = 100;
@@ -5314,7 +5314,8 @@ camera_trigger_capture (Camera *camera, GPContext *context)
/* sleep a bit perhaps ? or check events? */
} while (tries--);
- C_PTP_REP (nikon_wait_busy (params, 100, 20000)); /* lets wait 20 second */
+ /* busyness will be reported during the whole of the exposure time. */
+ C_PTP_REP (nikon_wait_busy (params, 100, 200*1000)); /* lets wait 200 seconds */
return GP_OK;
}
@@ -5348,7 +5349,7 @@ camera_trigger_capture (Camera *camera, GPContext *context)
return translate_ptp_result (ret);
} while (ret == PTP_RC_DeviceBusy);
- C_PTP_REP (nikon_wait_busy (params, 100, 20000)); /* lets wait 20 seconds */
+ C_PTP_REP (nikon_wait_busy (params, 100, 200*000)); /* lets wait 200 seconds */
return GP_OK;
}